@@ -1,6 +1,6 @@
 # pyenchant
 #
-# Copyright (C) 2004-2005, Ryan Kelly
+# Copyright (C) 2004-2008, Ryan Kelly
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -88,7 +88,6 @@ import unittest
 import re
 
 import enchant
-from enchant.utils import enumerate
 
 class Error(enchant.Error):
     """Exception subclass for the tokenize module.
@@ -115,6 +114,9 @@ class tokenize:
     def next(self):
         raise NotImplementedError()
 
+    def __next__(self):
+        return self.next()
+
     def __iter__(self):
         return self
 
@@ -311,6 +313,9 @@ class Filter:
     
         def __iter__(self):
             return self
+
+        def __next__(self):
+            return self.next()
     
         def next(self):
             # Try to get the next sub-token from word currently being split.
